%global libcurl_version 7.52.0

%undefine __cmake_in_source_build

%if 0%{?rhel}
%bcond_with zchunk
%else
%bcond_without zchunk
%endif

%if 0%{?fedora} >= 39 || 0%{?rhel} >= 10
%bcond_with use_gpgme
%bcond_with use_selinux
%else
%bcond_without use_gpgme
%bcond_without use_selinux
%endif

# Needs to match how gnupg2 is compiled
%bcond_with run_gnupg_user_socket

%bcond_with sanitizers

%if %{with use_gpgme} && %{with use_selinux}
%global need_selinux 1
%else
%global need_selinux 0
%endif

%global dnf_conflict 2.8.8

Name:           librepo
Version:        1.20.0
Release:        1.20250617094302728839.pr344.28.g899af5c%{?dist}
Summary:        Repodata downloading library

License:        LGPL-2.1-or-later
URL:            https://github.com/rpm-software-management/librepo
Source0:        librepo-1.20.0.tar.gz

BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  check-devel
BuildRequires:  doxygen
BuildRequires:  pkgconfig(glib-2.0) >= 2.66
%if %{with use_gpgme}
BuildRequires:  gpgme-devel
%else
BuildRequires:  pkgconfig(rpm) >= 4.18.0
%endif
BuildRequires:  libattr-devel
BuildRequires:  libcurl-devel >= %{libcurl_version}
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libcrypto)
%if %{need_selinux}
BuildRequires:  pkgconfig(libselinux)
%endif
BuildRequires:  pkgconfig(openssl)
%if %{with zchunk}
BuildRequires:  pkgconfig(zck) >= 0.9.11
%endif
Requires:       libcurl%{?_isa} >= %{libcurl_version}

%if %{with sanitizers}
BuildRequires:  libasan
BuildRequires:  liblsan
BuildRequires:  libubsan
%endif

%description
A library providing C and Python (libcURL like) API to downloading repository
metadata.

%package devel
Summary:        Repodata downloading library
Requires:       %{name}%{?_isa} = %{version}-%{release}
%if %{with zchunk}
Requires:       zchunk-devel%{?_isa}
%endif

%description devel
Development files for librepo.

%package -n python3-%{name}
Summary:        Python 3 bindings for the librepo library
%{?python_provide:%python_provide python3-%{name}}
BuildRequires:  python3-devel
BuildRequires:  python3-gpg
BuildRequires:  python3-pyxattr
BuildRequires:  python3-requests
BuildRequires:  python3-sphinx
Requires:       %{name}%{?_isa} = %{version}-%{release}
# Obsoletes Fedora 27 package
Obsoletes:      platform-python-%{name} < %{version}-%{release}
Conflicts:      python3-dnf < %{dnf_conflict}

%description -n python3-%{name}
Python 3 bindings for the librepo library.

%prep
%autosetup -p1 -n librepo-1.20.0

%build
%cmake \
    -DWITH_ZCHUNK=%{?with_zchunk:ON}%{!?with_zchunk:OFF} \
    -DUSE_GPGME=%{?with_use_gpgme:ON}%{!?with_use_gpgme:OFF} \
    -DUSE_RUN_GNUPG_USER_SOCKET=%{?with_run_gnupg_user_socket:ON}%{!?with_run_gnupg_user_socket:OFF} \
    -DWITH_SANITIZERS=%{?with_sanitizers:ON}%{!?with_sanitizers:OFF} \
%if %{need_selinux}
    -DENABLE_SELINUX=ON
%else
    -DENABLE_SELINUX=OFF
%endif
%cmake_build

%check
%ctest

%install
%cmake_install

%if 0%{?rhel} && 0%{?rhel} <= 7
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%else
%ldconfig_scriptlets
%endif

%files
%license COPYING
%doc README.md
%{_libdir}/%{name}.so.*

%files devel
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/

%files -n python3-%{name}
%{python3_sitearch}/%{name}/

%changelog
* Tue Jun 17 2025 Packit <hello@packit.dev> - 1.20.0-1.20250617094302728839.pr344.28.g899af5c
- We cannot build for epel-8 due to glib2 ≥ 2.66 requirement (Aleš Matěj)
- Add packit copr-builds and tests (Aleš Matěj)
- test: Use 1 instead of true (Petr Písař)
- Use 0 instead of `false` for assert (Aleš Matěj)
- ci: Remove "DNF CI" workflow (Evan Goode)
- Propagate return value from `prepare_repo_download_targets` (Aleš Matěj)
- cmake: doxygen is required for the "doc" target (Marek Blaha)
- `lr_download_metadata`: download metalink/mirrorlist in parallel (Aleš Matěj)
- `lr_download_metadata`: support handle `fetchmirrors` and `update` (Aleš Matěj)
- MetadataDowload: Move endcb handling to more general location (Aleš Matěj)
- Add missing end callback for already downloaded zchunk files (Aleš Matěj)
- `LrMetadataTarget` callbacks override associated `LrHandle` callbacks (Aleš Matěj)
- Propagate download target error to its metadata target (Aleš Matěj)
- Since we reuse the error in a loop in `process_repomd_xml` clear it (Aleš Matěj)
- lr_download_metadata: call endcb if we failed to download repomd (Aleš Matěj)
- Due to significant changes in `lr_download_metadata()` API bumb version (Aleš Matěj)
- Add C and Python examples for `lr_download_metadata(...)` (Aleš Matěj)
- Use `LrMetadataTarget` callbacks also when downloading repomd.xml (Aleš Matěj)
- Fix `lr_download_metadata` API (Aleš Matěj)
- Fix a memory leak of the glib slist of GSList *download_targets (Aleš Matěj)
- LrMetadataTarget: fix memory leak of repo and repomd (Aleš Matěj)
- Since `gnupghomedir` is optional allow `None` and check before using it (Aleš Matěj)
- Fix c examples makefile (Aleš Matěj)
- Fix CI by passing the built packages urls (Aleš Matěj)
- test_yum_package_downloading.py: Don't hardcode a value for EOPNOTSUPP (Adrian Bunk)
- Make documentation builds reproducible (Mihai Moldovan)
- Prefer pkgconf to find gpgme (Luca Boccassi)
- Enable automatic PR reviews (Jan Kolarik)
